Print

Print


Commit in lcsim/src/org/lcsim/recon/cluster/mst on MAIN
MSTPhotonFinder.java+14-21.2 -> 1.3
MSTPhotonFinderDriver.java+2-11.1 -> 1.2
+16-3
2 modified files
MJC: Modify photon-finder to watch out for barrel/endcap corners

lcsim/src/org/lcsim/recon/cluster/mst
MSTPhotonFinder.java 1.2 -> 1.3
diff -u -r1.1 -r1.2
--- MSTPhotonFinderDriver.java	11 Aug 2006 23:31:25 -0000	1.1
+++ MSTPhotonFinderDriver.java	15 May 2007 01:52:45 -0000	1.2
@@ -12,7 +12,7 @@
 /**
  * Driver wrapper around the MSTPhotonFinder class.
  *
- * @version $Id: MSTPhotonFinderDriver.java,v 1.1 2006/08/11 23:31:25 mcharles Exp $
+ * @version $Id: MSTPhotonFinderDriver.java,v 1.2 2007/05/15 01:52:45 mcharles Exp $
  */
 
 public class MSTPhotonFinderDriver extends Driver
@@ -26,6 +26,7 @@
     public void process(EventHeader event) {
 	super.process(event);
 	HitMap hits = (HitMap) (event.get(m_inputHitMapName));
+	m_finder.initPerEventInfo(event);
 	List<Cluster> photons = m_finder.createClusters(hits);
 	event.put(m_outputClusterListName, photons);
 	// Build output HitMap
CVSspam 0.2.8
diff -u -r1.2 -r1.3
--- MSTPhotonFinder.java	2 Nov 2006 23:06:55 -0000	1.2
+++ MSTPhotonFinder.java	15 May 2007 01:52:45 -0000	1.3
@@ -11,12 +11,13 @@
 import org.lcsim.recon.cluster.util.ClusterFirstLayerDecision;
 import org.lcsim.recon.cluster.util.ClusterLayerSeparationDecision;
 import org.lcsim.recon.cluster.util.BasicCluster;
+import org.lcsim.event.EventHeader;
 
 /**
  * Class to reconstruct and select photon clusters in the ECAL.
  * Conforms to the Clusterer interface.
  *
- * @version $Id: MSTPhotonFinder.java,v 1.2 2006/11/02 23:06:55 mcharles Exp $
+ * @version $Id: MSTPhotonFinder.java,v 1.3 2007/05/15 01:52:45 mcharles Exp $
  */
 
 public class MSTPhotonFinder implements Clusterer 
@@ -27,7 +28,12 @@
 	m_shapeDec.setMaximum(null,null,null);
     }
 
+    public void initPerEventInfo(EventHeader event) {
+	m_event = event;
+    }
+
     // Config stuff
+    protected EventHeader m_event = null;
     protected List<Cluster> m_MIPVetoList = null;
     protected double m_coreThreshold = 7.5; // default (mm)
     protected double m_fragThreshold = 75.0; // default (mm)
@@ -101,7 +107,13 @@
 	// Set up the decision-maker to identify valid photon cores
 	AndDecisionMakerSingle<Cluster> coreInputDecision = new AndDecisionMakerSingle<Cluster>();
 	coreInputDecision.addDecisionMaker(new ClusterSizeDecision(m_coreSizeMinimum)); // Require >= n hits
-	coreInputDecision.addDecisionMaker(new ClusterFirstLayerDecision(m_coreFirstLayerRange)); // Require first hit in first n layers
+	{
+	    ClusterFirstLayerDecision dec = new ClusterFirstLayerDecision(m_coreFirstLayerRange); // Require first hit in first n layers
+	    dec.setIgnoreCorners(true); // Don't use hits in the corners
+	    dec.initGeometry(m_event);
+	    coreInputDecision.addDecisionMaker(dec);
+	    
+	}
 	if (m_MIPVetoList != null) {
 	    // NOT YET IMPLEMENTED
 	    //List<Cluster> mipList = event.get(Cluster.class, m_MIPVetoList);

lcsim/src/org/lcsim/recon/cluster/mst
MSTPhotonFinderDriver.java 1.1 -> 1.2